@@ -1,8 +1,8 @@
 package org.gcube.portlets.user.td.resourceswidget.client;
 
-import org.gcube.portlets.user.td.gwtservice.shared.user.UserInfo;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
+import com.google.gwt.core.client.GWT;
 import com.google.web.bindery.event.shared.EventBus;
 import com.sencha.gxt.widget.core.client.Window;
 import com.sencha.gxt.widget.core.client.event.SelectEvent;
@@ -16,32 +16,33 @@ import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;
  *
  */
 public class ResourcesDialog extends Window {
-	protected String WIDTH = "320px";
-	protected String HEIGHT = "540px";
-	protected TRId trId;
-	protected EventBus eventBus;
-	protected UserInfo userInfo;
+	private static final String WIDTH = "320px";
+	private static final String HEIGHT = "540px";
+	private ResourcesMessages msgs;
 	
 	public ResourcesDialog(TRId trId,  EventBus eventBus) {
-		this.trId = trId;
-		
-		this.eventBus=eventBus;
+		initMessages();
 		initWindow();
-		
 		ResourcesPanel resourcesPanel= new ResourcesPanel(this, trId, eventBus);
 		add(resourcesPanel);
 	}
 	
+	protected void initMessages(){
+		msgs = GWT.create(ResourcesMessages.class);
+	}
+	
 	protected void initWindow() {
 		setWidth(WIDTH);
 		setHeight(HEIGHT);
 		setBodyBorder(false);
 		setResizable(false);
-		setHeadingText("Resources");
+		setHeadingText(msgs.resourcesDialogHead());
 		//getHeader().setIcon(Resources.IMAGES.side_list());
 	}
 	
 	
+	
+	
 	/**
 	 * {@inheritDoc}
 	 */
